# MapAttributesQuestion

A question to the Open Policy Agent to map information about the user to a set of flattened attributes. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**input** | [**MapAttributesQuestionInput**](MapAttributesQuestionInput.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


